from pysqa.queueadapter import QueueAdapter

from ._version import get_versions

__all__ = ["QueueAdapter"]
__version__ = get_versions()["version"]
